@@ -20,7 +20,7 @@ emulation of DNS
 
 
 our $VERSION;
-$VERSION = '0.008';
+$VERSION = '0.009';
 
 use warnings;
 use strict;
@@ -196,17 +196,12 @@ methods.
 sub send {
     my $self = shift;
     
-    # We could be passed a Net::DNS::Packet object, or a set of strings; handle
-    # both
-    my ($packet, $question);
-    if (Scalar::Util::blessed($_[0]) && $_[0]->isa('Net::DNS::Packet')) {
-        $packet = $_[0];
-        # TODO: is it a safe assumption that a packet we're passed will only
-        # contain one Question object?
-        ($question) = $packet->question;
-    } else {
-        $question = Net::DNS::Question->new(@_);
-    }
+    # We could be passed a Net::DNS::Packet object, or an array of strings
+    my ($query) = @_;
+    $query = Net::DNS::Packet->new(@_) unless ref ($query);
+
+    my ($question) = $query->question;
+
     my $domain   = lc($question->qname);
     my $rr_type  = $question->qtype;
     my $class    = $question->qclass;
@@ -236,8 +231,7 @@ sub send {
             }
         }
         
-        my $response_packet = Net::DNS::Packet->new($domain, $rr_type, $class);
-        $response_packet->header->qr(TRUE);
+        my $response_packet = $query->reply;
         $response_packet->header->rcode($result);
         $response_packet->header->aa($aa);
         $response_packet->push(answer => @answer_rrs);
